==> rt-4.0.0-sources.jar: com/sun/xml/ws/resources/EncodingMessages.java <==
/*
 * Copyright (c) 1997, 2020 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Distribution License v. 1.0, which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

package com.sun.xml.ws.resources;

import java.util.Locale;
import java.util.ResourceBundle;
import com.sun.istack.localization.Localizable;
import com.sun.istack.localization.LocalizableMessageFactory;
import com.sun.istack.localization.LocalizableMessageFactory.ResourceBundleSupplier;
import com.sun.istack.localization.Localizer;


/**
 * Defines string formatting method for each constant in the resource file
 * 
 */
public final class EncodingMessages {

    private final static String BUNDLE_NAME = "com.sun.xml.ws.resources.encoding";
    private final static LocalizableMessageFactory MESSAGE_FACTORY = new LocalizableMessageFactory(BUNDLE_NAME, new EncodingMessages.BundleSupplier());
    private final static Localizer LOCALIZER = new Localizer();

    private EncodingMessages() {
    }

    public static Localizable localizableEXCEPTION_NOTFOUND(Object arg0) {
        return MESSAGE_FACTORY.getMessage("exception.notfound", arg0);
    }

    /**
     * exception class: {0} not found in the model!
     * 
     */
    public static String EXCEPTION_NOTFOUND(Object arg0) {
        return LOCALIZER.localize(localizableEXCEPTION_NOTFOUND(arg0));
    }

    public static Localizable localizableXSD_UNKNOWN_PREFIX(Object arg0) {
        return MESSAGE_FACTORY.getMessage("xsd.unknownPrefix", arg0);
    }

    /**
     * unknown prefix "{0}"
     * 
     */
    public static String XSD_UNKNOWN_PREFIX(Object arg0) {
        return LOCALIZER.localize(localizableXSD_UNKNOWN_PREFIX(arg0));
    }

    public static Localizable localizableNESTED_ENCODING_ERROR(Object arg0) {
        return MESSAGE_FACTORY.getMessage("nestedEncodingError", arg0);
    }

    /**
     * encoding error: {0}
     * 
     */
    public static String NESTED_ENCODING_ERROR(Object arg0) {
        return LOCALIZER.localize(localizableNESTED_ENCODING_ERROR(arg0));
    }

    public static Localizable localizableNESTED_DESERIALIZATION_ERROR(Object arg0) {
        return MESSAGE_FACTORY.getMessage("nestedDeserializationError", arg0);
    }

    /**
     * deserialization error: {0}
     * 
     */
    public static String NESTED_DESERIALIZATION_ERROR(Object arg0) {
        return LOCALIZER.localize(localizableNESTED_DESERIALIZATION_ERROR(arg0));
    }

    public static Localizable localizableXSD_UNEXPECTED_ELEMENT_NAME(Object arg0, Object arg1) {
        return MESSAGE_FACTORY.getMessage("xsd.unexpectedElementName", arg0, arg1);
    }

    /**
     * unexpected element name: expected={0}, actual: {1}
     * 
     */
    public static String XSD_UNEXPECTED_ELEMENT_NAME(Object arg0, Object arg1) {
        return LOCALIZER.localize(localizableXSD_UNEXPECTED_ELEMENT_NAME(arg0, arg1));
    }

    public static Localizable localizableFAILED_TO_READ_RESPONSE(Object arg0) {
        return MESSAGE_FACTORY.getMessage("failed.to.read.response", arg0);
    }

    /**
     * Failed to read a response: {0}
     * 
     */
    public static String FAILED_TO_READ_RESPONSE(Object arg0) {
        return LOCALIZER.localize(localizableFAILED_TO_READ_RESPONSE(arg0));
    }

    public static Localizable localizableNESTED_SERIALIZATION_ERROR(Object arg0) {
        return MESSAGE_FACTORY.getMessage("nestedSerializationError", arg0);
    }

    /**
     * serialization error: {0}
     * 
     */
    public static String NESTED_SERIALIZATION_ERROR(Object arg0) {
        return LOCALIZER.localize(localizableNESTED_SERIALIZATION_ERROR(arg0));
    }

    public static Localizable localizableNO_SUCH_CONTENT_ID(Object arg0) {
        return MESSAGE_FACTORY.getMessage("noSuchContentId", arg0);
    }

    /**
     * There''s no attachment for the content ID "{0}"
     * 
     */
    public static String NO_SUCH_CONTENT_ID(Object arg0) {
        return LOCALIZER.localize(localizableNO_SUCH_CONTENT_ID(arg0));
    }

    public static Localizable localizableEXCEPTION_INCORRECT_TYPE(Object arg0) {
        return MESSAGE_FACTORY.getMessage("exception.incorrectType", arg0);
    }

    /**
     * incorrect type. Expected java.lang.Exception, found {0}
     * 
     */
    public static String EXCEPTION_INCORRECT_TYPE(Object arg0) {
        return LOCALIZER.localize(localizableEXCEPTION_INCORRECT_TYPE(arg0));
    }

    private static class BundleSupplier
        implements ResourceBundleSupplier
    {


        public ResourceBundle getResourceBundle(Locale locale) {
            return ResourceBundle.getBundle(BUNDLE_NAME, locale);
        }

    }

}

==> rt-4.0.2-sources.jar: com/sun/xml/ws/resources/EncodingMessages.java <==
/*
 * Copyright (c) 1997, 2020 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Distribution License v. 1.0, which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

package com.sun.xml.ws.resources;

import java.util.Locale;
import java.util.ResourceBundle;
import com.sun.istack.localization.Localizable;
import com.sun.istack.localization.LocalizableMessageFactory;
import com.sun.istack.localization.LocalizableMessageFactory.ResourceBundleSupplier;
import com.sun.istack.localization.Localizer;


/**
 * Defines string formatting method for each constant in the resource file
 * 
 */
public final class EncodingMessages {

    private static final String BUNDLE_NAME = "com.sun.xml.ws.resources.encoding";
    private static final LocalizableMessageFactory MESSAGE_FACTORY = new LocalizableMessageFactory(BUNDLE_NAME, new EncodingMessages.BundleSupplier());
    private static final Localizer LOCALIZER = new Localizer();

    private EncodingMessages() {
    }

    public static Localizable localizableEXCEPTION_NOTFOUND(Object arg0) {
        return MESSAGE_FACTORY.getMessage("exception.notfound", arg0);
    }

    /**
     * exception class: {0} not found in the model!
     * 
     */
    public static String EXCEPTION_NOTFOUND(Object arg0) {
        return LOCALIZER.localize(localizableEXCEPTION_NOTFOUND(arg0));
    }

    public static Localizable localizableXSD_UNKNOWN_PREFIX(Object arg0) {
        return MESSAGE_FACTORY.getMessage("xsd.unknownPrefix", arg0);
    }

    /**
     * unknown prefix "{0}"
     * 
     */
    public static String XSD_UNKNOWN_PREFIX(Object arg0) {
        return LOCALIZER.localize(localizableXSD_UNKNOWN_PREFIX(arg0));
    }

    public static Localizable localizableNESTED_ENCODING_ERROR(Object arg0) {
        return MESSAGE_FACTORY.getMessage("nestedEncodingError", arg0);
    }

    /**
     * encoding error: {0}
     * 
     */
    public static String NESTED_ENCODING_ERROR(Object arg0) {
        return LOCALIZER.localize(localizableNESTED_ENCODING_ERROR(arg0));
    }

    public static Localizable localizableNESTED_DESERIALIZATION_ERROR(Object arg0) {
        return MESSAGE_FACTORY.getMessage("nestedDeserializationError", arg0);
    }

    /**
     * deserialization error: {0}
     * 
     */
    public static String NESTED_DESERIALIZATION_ERROR(Object arg0) {
        return LOCALIZER.localize(localizableNESTED_DESERIALIZATION_ERROR(arg0));
    }

    public static Localizable localizableXSD_UNEXPECTED_ELEMENT_NAME(Object arg0, Object arg1) {
        return MESSAGE_FACTORY.getMessage("xsd.unexpectedElementName", arg0, arg1);
    }

    /**
     * unexpected element name: expected={0}, actual: {1}
     * 
     */
    public static String XSD_UNEXPECTED_ELEMENT_NAME(Object arg0, Object arg1) {
        return LOCALIZER.localize(localizableXSD_UNEXPECTED_ELEMENT_NAME(arg0, arg1));
    }

    public static Localizable localizableFAILED_TO_READ_RESPONSE(Object arg0) {
        return MESSAGE_FACTORY.getMessage("failed.to.read.response", arg0);
    }

    /**
     * Failed to read a response: {0}
     * 
     */
    public static String FAILED_TO_READ_RESPONSE(Object arg0) {
        return LOCALIZER.localize(localizableFAILED_TO_READ_RESPONSE(arg0));
    }

    public static Localizable localizableNESTED_SERIALIZATION_ERROR(Object arg0) {
        return MESSAGE_FACTORY.getMessage("nestedSerializationError", arg0);
    }

    /**
     * serialization error: {0}
     * 
     */
    public static String NESTED_SERIALIZATION_ERROR(Object arg0) {
        return LOCALIZER.localize(localizableNESTED_SERIALIZATION_ERROR(arg0));
    }

    public static Localizable localizableNO_SUCH_CONTENT_ID(Object arg0) {
        return MESSAGE_FACTORY.getMessage("noSuchContentId", arg0);
    }

    /**
     * There''s no attachment for the content ID "{0}"
     * 
     */
    public static String NO_SUCH_CONTENT_ID(Object arg0) {
        return LOCALIZER.localize(localizableNO_SUCH_CONTENT_ID(arg0));
    }

    public static Localizable localizableEXCEPTION_INCORRECT_TYPE(Object arg0) {
        return MESSAGE_FACTORY.getMessage("exception.incorrectType", arg0);
    }

    /**
     * incorrect type. Expected java.lang.Exception, found {0}
     * 
     */
    public static String EXCEPTION_INCORRECT_TYPE(Object arg0) {
        return LOCALIZER.localize(localizableEXCEPTION_INCORRECT_TYPE(arg0));
    }

    private static class BundleSupplier
        implements ResourceBundleSupplier
    {


        public ResourceBundle getResourceBundle(Locale locale) {
            return ResourceBundle.getBundle(BUNDLE_NAME, locale);
        }

    }

}
